# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messages.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import getgauge.messages.spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0emessages.proto\x12\x0egauge.messages\x1a\nspec.proto\"\x14\n\x12KillProcessRequest\"X\n\x17\x45xecutionStatusResponse\x12=\n\x0f\x65xecutionResult\x18\x01 \x01(\x0b\x32$.gauge.messages.ProtoExecutionResult\"\x9e\x01\n\x18\x45xecutionStartingRequest\x12;\n\x14\x63urrentExecutionInfo\x18\x01 \x01(\x0b\x32\x1d.gauge.messages.ExecutionInfo\x12\x35\n\x0bsuiteResult\x18\x02 \x01(\x0b\x32 .gauge.messages.ProtoSuiteResult\x12\x0e\n\x06stream\x18\x03 \x01(\x05\"\x9c\x01\n\x16\x45xecutionEndingRequest\x12;\n\x14\x63urrentExecutionInfo\x18\x01 \x01(\x0b\x32\x1d.gauge.messages.ExecutionInfo\x12\x35\n\x0bsuiteResult\x18\x02 \x01(\x0b\x32 .gauge.messages.ProtoSuiteResult\x12\x0e\n\x06stream\x18\x03 \x01(\x05\"\xa0\x01\n\x1cSpecExecutionStartingRequest\x12;\n\x14\x63urrentExecutionInfo\x18\x01 \x01(\x0b\x32\x1d.gauge.messages.ExecutionInfo\x12\x33\n\nspecResult\x18\x02 \x01(\x0b\x32\x1f.gauge.messages.ProtoSpecResult\x12\x0e\n\x06stream\x18\x03 \x01(\x05\"\x9e\x01\n\x1aSpecExecutionEndingRequest\x12;\n\x14\x63urrentExecutionInfo\x18\x01 \x01(\x0b\x32\x1d.gauge.messages.ExecutionInfo\x12\x33\n\nspecResult\x18\x02 \x01(\x0b\x32\x1f.gauge.messages.ProtoSpecResult\x12\x0e\n\x06stream\x18\x03 \x01(\x05\"\xac\x01\n ScenarioExecutionStartingRequest\x12;\n\x14\x63urrentExecutionInfo\x18\x01 \x01(\x0b\x32\x1d.gauge.messages.ExecutionInfo\x12;\n\x0escenarioResult\x18\x02 \x01(\x0b\x32#.gauge.messages.ProtoScenarioResult\x12\x0e\n\x06stream\x18\x03 \x01(\x05\"\xaa\x01\n\x1eScenarioExecutionEndingRequest\x12;\n\x14\x63urrentExecutionInfo\x18\x01 \x01(\x0b\x32\x1d.gauge.messages.ExecutionInfo\x12;\n\x0escenarioResult\x18\x02 \x01(\x0b\x32#.gauge.messages.ProtoScenarioResult\x12\x0e\n\x06stream\x18\x03 \x01(\x05\"\xa0\x01\n\x1cStepExecutionStartingRequest\x12;\n\x14\x63urrentExecutionInfo\x18\x01 \x01(\x0b\x32\x1d.gauge.messages.ExecutionInfo\x12\x33\n\nstepResult\x18\x02 \x01(\x0b\x32\x1f.gauge.messages.ProtoStepResult\x12\x0e\n\x06stream\x18\x03 \x01(\x05\"\x9e\x01\n\x1aStepExecutionEndingRequest\x12;\n\x14\x63urrentExecutionInfo\x18\x01 \x01(\x0b\x32\x1d.gauge.messages.ExecutionInfo\x12\x33\n\nstepResult\x18\x02 \x01(\x0b\x32\x1f.gauge.messages.ProtoStepResult\x12\x0e\n\x06stream\x18\x03 \x01(\x05\"3\n\x0c\x45xecutionArg\x12\x10\n\x08\x66lagName\x18\x01 \x01(\t\x12\x11\n\tflagValue\x18\x02 \x03(\t\"\xb6\x02\n\rExecutionInfo\x12-\n\x0b\x63urrentSpec\x18\x01 \x01(\x0b\x32\x18.gauge.messages.SpecInfo\x12\x35\n\x0f\x63urrentScenario\x18\x02 \x01(\x0b\x32\x1c.gauge.messages.ScenarioInfo\x12-\n\x0b\x63urrentStep\x18\x03 \x01(\x0b\x32\x18.gauge.messages.StepInfo\x12\x12\n\nstacktrace\x18\x04 \x01(\t\x12\x13\n\x0bprojectName\x18\x05 \x01(\t\x12\x33\n\rExecutionArgs\x18\x06 \x03(\x0b\x32\x1c.gauge.messages.ExecutionArg\x12 \n\x18numberOfExecutionStreams\x18\x07 \x01(\x05\x12\x10\n\x08runnerId\x18\x08 \x01(\x05\"J\n\x08SpecInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x66ileName\x18\x02 \x01(\t\x12\x10\n\x08isFailed\x18\x03 \x01(\x08\x12\x0c\n\x04tags\x18\x04 \x03(\t\"<\n\x0cScenarioInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08isFailed\x18\x02 \x01(\x08\x12\x0c\n\x04tags\x18\x03 \x03(\t\"x\n\x08StepInfo\x12\x30\n\x04step\x18\x01 \x01(\x0b\x32\".gauge.messages.ExecuteStepRequest\x12\x10\n\x08isFailed\x18\x02 \x01(\x08\x12\x12\n\nstackTrace\x18\x03 \x01(\t\x12\x14\n\x0c\x65rrorMessage\x18\x04 \x01(\t\"\x9c\x01\n\x12\x45xecuteStepRequest\x12\x16\n\x0e\x61\x63tualStepText\x18\x01 \x01(\t\x12\x16\n\x0eparsedStepText\x18\x02 \x01(\t\x12\x17\n\x0fscenarioFailing\x18\x03 \x01(\x08\x12-\n\nparameters\x18\x04 \x03(\x0b\x32\x19.gauge.messages.Parameter\x12\x0e\n\x06stream\x18\x05 \x01(\x05\"v\n\x13StepValidateRequest\x12\x10\n\x08stepText\x18\x01 \x01(\t\x12\x1a\n\x12numberOfParameters\x18\x02 \x01(\x05\x12\x31\n\tstepValue\x18\x03 \x01(\x0b\x32\x1e.gauge.messages.ProtoStepValue\"\xe7\x01\n\x14StepValidateResponse\x12\x0f\n\x07isValid\x18\x01 \x01(\x08\x12\x14\n\x0c\x65rrorMessage\x18\x02 \x01(\t\x12\x41\n\terrorType\x18\x03 \x01(\x0e\x32..gauge.messages.StepValidateResponse.ErrorType\x12\x12\n\nsuggestion\x18\x04 \x01(\t\"Q\n\tErrorType\x12!\n\x1dSTEP_IMPLEMENTATION_NOT_FOUND\x10\x00\x12!\n\x1d\x44UPLICATE_STEP_IMPLEMENTATION\x10\x01\"M\n\x14SuiteExecutionResult\x12\x35\n\x0bsuiteResult\x18\x01 \x01(\x0b\x32 .gauge.messages.ProtoSuiteResult\"I\n\x18SuiteExecutionResultItem\x12-\n\nresultItem\x18\x01 \x01(\x0b\x32\x19.gauge.messages.ProtoItem\"\x12\n\x10StepNamesRequest\"\"\n\x11StepNamesResponse\x12\r\n\x05steps\x18\x01 \x03(\t\".\n\x1cScenarioDataStoreInitRequest\x12\x0e\n\x06stream\x18\x01 \x01(\x05\"*\n\x18SpecDataStoreInitRequest\x12\x0e\n\x06stream\x18\x01 \x01(\x05\"+\n\x19SuiteDataStoreInitRequest\x12\x0e\n\x06stream\x18\x01 \x01(\x05\"=\n\x11ParameterPosition\x12\x13\n\x0boldPosition\x18\x01 \x01(\x05\x12\x13\n\x0bnewPosition\x18\x02 \x01(\x05\"\xcd\x01\n\x0fRefactorRequest\x12\x34\n\x0coldStepValue\x18\x01 \x01(\x0b\x32\x1e.gauge.messages.ProtoStepValue\x12\x34\n\x0cnewStepValue\x18\x02 \x01(\x0b\x32\x1e.gauge.messages.ProtoStepValue\x12\x39\n\x0eparamPositions\x18\x03 \x03(\x0b\x32!.gauge.messages.ParameterPosition\x12\x13\n\x0bsaveChanges\x18\x04 \x01(\x08\"a\n\x0b\x46ileChanges\x12\x10\n\x08\x66ileName\x18\x01 \x01(\t\x12\x17\n\x0b\x66ileContent\x18\x02 \x01(\tB\x02\x18\x01\x12\'\n\x05\x64iffs\x18\x03 \x03(\x0b\x32\x18.gauge.messages.TextDiff\"z\n\x10RefactorResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x14\n\x0c\x66ilesChanged\x18\x03 \x03(\t\x12\x30\n\x0b\x66ileChanges\x18\x04 \x03(\x0b\x32\x1b.gauge.messages.FileChanges\"$\n\x0fStepNameRequest\x12\x11\n\tstepValue\x18\x01 \x01(\t\"\x97\x01\n\x10StepNameResponse\x12\x15\n\risStepPresent\x18\x01 \x01(\x08\x12\x10\n\x08stepName\x18\x02 \x03(\t\x12\x10\n\x08hasAlias\x18\x03 \x01(\x08\x12\x10\n\x08\x66ileName\x18\x04 \x01(\t\x12\"\n\x04span\x18\x05 \x01(\x0b\x32\x14.gauge.messages.Span\x12\x12\n\nisExternal\x18\x06 \x01(\x08\"-\n\x1aUnsupportedMessageResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xd1\x01\n\x10\x43\x61\x63heFileRequest\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x10\n\x08\x66ilePath\x18\x02 \x01(\t\x12\x10\n\x08isClosed\x18\x03 \x01(\x08\x12;\n\x06status\x18\x04 \x01(\x0e\x32+.gauge.messages.CacheFileRequest.FileStatus\"K\n\nFileStatus\x12\x0b\n\x07\x43HANGED\x10\x00\x12\n\n\x06\x43LOSED\x10\x01\x12\x0b\n\x07\x43REATED\x10\x02\x12\x0b\n\x07\x44\x45LETED\x10\x03\x12\n\n\x06OPENED\x10\x04\"(\n\x14StepPositionsRequest\x12\x10\n\x08\x66ilePath\x18\x01 \x01(\t\"\xb8\x01\n\x15StepPositionsResponse\x12I\n\rstepPositions\x18\x01 \x03(\x0b\x32\x32.gauge.messages.StepPositionsResponse.StepPosition\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x1a\x45\n\x0cStepPosition\x12\x11\n\tstepValue\x18\x01 \x01(\t\x12\"\n\x04span\x18\x02 \x01(\x0b\x32\x14.gauge.messages.Span\"&\n$ImplementationFileGlobPatternRequest\"=\n%ImplementationFileGlobPatternResponse\x12\x14\n\x0cglobPatterns\x18\x01 \x03(\t\"\x1f\n\x1dImplementationFileListRequest\"A\n\x1eImplementationFileListResponse\x12\x1f\n\x17implementationFilePaths\x18\x01 \x03(\t\"N\n\x1dStubImplementationCodeRequest\x12\x1e\n\x16implementationFilePath\x18\x01 \x01(\t\x12\r\n\x05\x63odes\x18\x02 \x03(\t\"?\n\x08TextDiff\x12\"\n\x04span\x18\x01 \x01(\x0b\x32\x14.gauge.messages.Span\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\"I\n\x08\x46ileDiff\x12\x10\n\x08\x66ilePath\x18\x01 \x01(\t\x12+\n\ttextDiffs\x18\x02 \x03(\x0b\x32\x18.gauge.messages.TextDiff\"\x1d\n\tKeepAlive\x12\x10\n\x08pluginId\x18\x01 \x01(\t\"\xa9\x01\n\x0bSpecDetails\x12\x37\n\x07\x64\x65tails\x18\x01 \x03(\x0b\x32&.gauge.messages.SpecDetails.SpecDetail\x1a\x61\n\nSpecDetail\x12\'\n\x04spec\x18\x01 \x01(\x0b\x32\x19.gauge.messages.ProtoSpec\x12*\n\x0bparseErrors\x18\x02 \x03(\x0b\x32\x15.gauge.messages.Error\"\x07\n\x05\x45mpty\"\xfd\x1b\n\x07Message\x12\x38\n\x0bmessageType\x18\x01 \x01(\x0e\x32#.gauge.messages.Message.MessageType\x12\x11\n\tmessageId\x18\x02 \x01(\x03\x12J\n\x18\x65xecutionStartingRequest\x18\x03 \x01(\x0b\x32(.gauge.messages.ExecutionStartingRequest\x12R\n\x1cspecExecutionStartingRequest\x18\x04 \x01(\x0b\x32,.gauge.messages.SpecExecutionStartingRequest\x12N\n\x1aspecExecutionEndingRequest\x18\x05 \x01(\x0b\x32*.gauge.messages.SpecExecutionEndingRequest\x12Z\n scenarioExecutionStartingRequest\x18\x06 \x01(\x0b\x32\x30.gauge.messages.ScenarioExecutionStartingRequest\x12V\n\x1escenarioExecutionEndingRequest\x18\x07 \x01(\x0b\x32..gauge.messages.ScenarioExecutionEndingRequest\x12R\n\x1cstepExecutionStartingRequest\x18\x08 \x01(\x0b\x32,.gauge.messages.StepExecutionStartingRequest\x12N\n\x1astepExecutionEndingRequest\x18\t \x01(\x0b\x32*.gauge.messages.StepExecutionEndingRequest\x12>\n\x12\x65xecuteStepRequest\x18\n \x01(\x0b\x32\".gauge.messages.ExecuteStepRequest\x12\x46\n\x16\x65xecutionEndingRequest\x18\x0b \x01(\x0b\x32&.gauge.messages.ExecutionEndingRequest\x12@\n\x13stepValidateRequest\x18\x0c \x01(\x0b\x32#.gauge.messages.StepValidateRequest\x12\x42\n\x14stepValidateResponse\x18\r \x01(\x0b\x32$.gauge.messages.StepValidateResponse\x12H\n\x17\x65xecutionStatusResponse\x18\x0e \x01(\x0b\x32\'.gauge.messages.ExecutionStatusResponse\x12:\n\x10stepNamesRequest\x18\x0f \x01(\x0b\x32 .gauge.messages.StepNamesRequest\x12<\n\x11stepNamesResponse\x18\x10 \x01(\x0b\x32!.gauge.messages.StepNamesResponse\x12\x42\n\x14suiteExecutionResult\x18\x11 \x01(\x0b\x32$.gauge.messages.SuiteExecutionResult\x12>\n\x12killProcessRequest\x18\x12 \x01(\x0b\x32\".gauge.messages.KillProcessRequest\x12R\n\x1cscenarioDataStoreInitRequest\x18\x13 \x01(\x0b\x32,.gauge.messages.ScenarioDataStoreInitRequest\x12J\n\x18specDataStoreInitRequest\x18\x14 \x01(\x0b\x32(.gauge.messages.SpecDataStoreInitRequest\x12L\n\x19suiteDataStoreInitRequest\x18\x15 \x01(\x0b\x32).gauge.messages.SuiteDataStoreInitRequest\x12\x38\n\x0fstepNameRequest\x18\x16 \x01(\x0b\x32\x1f.gauge.messages.StepNameRequest\x12:\n\x10stepNameResponse\x18\x17 \x01(\x0b\x32 .gauge.messages.StepNameResponse\x12\x38\n\x0frefactorRequest\x18\x18 \x01(\x0b\x32\x1f.gauge.messages.RefactorRequest\x12:\n\x10refactorResponse\x18\x19 \x01(\x0b\x32 .gauge.messages.RefactorResponse\x12N\n\x1aunsupportedMessageResponse\x18\x1a \x01(\x0b\x32*.gauge.messages.UnsupportedMessageResponse\x12:\n\x10\x63\x61\x63heFileRequest\x18\x1b \x01(\x0b\x32 .gauge.messages.CacheFileRequest\x12\x42\n\x14stepPositionsRequest\x18\x1c \x01(\x0b\x32$.gauge.messages.StepPositionsRequest\x12\x44\n\x15stepPositionsResponse\x18\x1d \x01(\x0b\x32%.gauge.messages.StepPositionsResponse\x12T\n\x1dimplementationFileListRequest\x18\x1e \x01(\x0b\x32-.gauge.messages.ImplementationFileListRequest\x12V\n\x1eimplementationFileListResponse\x18\x1f \x01(\x0b\x32..gauge.messages.ImplementationFileListResponse\x12T\n\x1dstubImplementationCodeRequest\x18  \x01(\x0b\x32-.gauge.messages.StubImplementationCodeRequest\x12*\n\x08\x66ileDiff\x18! \x01(\x0b\x32\x18.gauge.messages.FileDiff\x12\x62\n$implementationFileGlobPatternRequest\x18\" \x01(\x0b\x32\x34.gauge.messages.ImplementationFileGlobPatternRequest\x12\x64\n%implementationFileGlobPatternResponse\x18# \x01(\x0b\x32\x35.gauge.messages.ImplementationFileGlobPatternResponse\x12J\n\x18suiteExecutionResultItem\x18$ \x01(\x0b\x32(.gauge.messages.SuiteExecutionResultItem\x12,\n\tkeepAlive\x18% \x01(\x0b\x32\x19.gauge.messages.KeepAlive\"\xa2\x07\n\x0bMessageType\x12\x15\n\x11\x45xecutionStarting\x10\x00\x12\x19\n\x15SpecExecutionStarting\x10\x01\x12\x17\n\x13SpecExecutionEnding\x10\x02\x12\x1d\n\x19ScenarioExecutionStarting\x10\x03\x12\x1b\n\x17ScenarioExecutionEnding\x10\x04\x12\x19\n\x15StepExecutionStarting\x10\x05\x12\x17\n\x13StepExecutionEnding\x10\x06\x12\x0f\n\x0b\x45xecuteStep\x10\x07\x12\x13\n\x0f\x45xecutionEnding\x10\x08\x12\x17\n\x13StepValidateRequest\x10\t\x12\x18\n\x14StepValidateResponse\x10\n\x12\x1b\n\x17\x45xecutionStatusResponse\x10\x0b\x12\x14\n\x10StepNamesRequest\x10\x0c\x12\x15\n\x11StepNamesResponse\x10\r\x12\x16\n\x12KillProcessRequest\x10\x0e\x12\x18\n\x14SuiteExecutionResult\x10\x0f\x12\x19\n\x15ScenarioDataStoreInit\x10\x10\x12\x15\n\x11SpecDataStoreInit\x10\x11\x12\x16\n\x12SuiteDataStoreInit\x10\x12\x12\x13\n\x0fStepNameRequest\x10\x13\x12\x14\n\x10StepNameResponse\x10\x14\x12\x13\n\x0fRefactorRequest\x10\x15\x12\x14\n\x10RefactorResponse\x10\x16\x12\x1e\n\x1aUnsupportedMessageResponse\x10\x17\x12\x14\n\x10\x43\x61\x63heFileRequest\x10\x18\x12\x18\n\x14StepPositionsRequest\x10\x19\x12\x19\n\x15StepPositionsResponse\x10\x1a\x12!\n\x1dImplementationFileListRequest\x10\x1b\x12\"\n\x1eImplementationFileListResponse\x10\x1c\x12!\n\x1dStubImplementationCodeRequest\x10\x1d\x12\x0c\n\x08\x46ileDiff\x10\x1e\x12(\n$ImplementationFileGlobPatternRequest\x10\x1f\x12)\n%ImplementationFileGlobPatternResponse\x10 \x12\x1c\n\x18SuiteExecutionResultItem\x10!\x12\r\n\tKeepAlive\x10\"B\\\n\x16\x63om.thoughtworks.gaugeZ1github.com/getgauge/gauge-proto/go/gauge_messages\xaa\x02\x0eGauge.Messagesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'messages_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.thoughtworks.gaugeZ1github.com/getgauge/gauge-proto/go/gauge_messages\252\002\016Gauge.Messages'
  _FILECHANGES.fields_by_name['fileContent']._options = None
  _FILECHANGES.fields_by_name['fileContent']._serialized_options = b'\030\001'
  _globals['_KILLPROCESSREQUEST']._serialized_start=46
  _globals['_KILLPROCESSREQUEST']._serialized_end=66
  _globals['_EXECUTIONSTATUSRESPONSE']._serialized_start=68
  _globals['_EXECUTIONSTATUSRESPONSE']._serialized_end=156
  _globals['_EXECUTIONSTARTINGREQUEST']._serialized_start=159
  _globals['_EXECUTIONSTARTINGREQUEST']._serialized_end=317
  _globals['_EXECUTIONENDINGREQUEST']._serialized_start=320
  _globals['_EXECUTIONENDINGREQUEST']._serialized_end=476
  _globals['_SPECEXECUTIONSTARTINGREQUEST']._serialized_start=479
  _globals['_SPECEXECUTIONSTARTINGREQUEST']._serialized_end=639
  _globals['_SPECEXECUTIONENDINGREQUEST']._serialized_start=642
  _globals['_SPECEXECUTIONENDINGREQUEST']._serialized_end=800
  _globals['_SCENARIOEXECUTIONSTARTINGREQUEST']._serialized_start=803
  _globals['_SCENARIOEXECUTIONSTARTINGREQUEST']._serialized_end=975
  _globals['_SCENARIOEXECUTIONENDINGREQUEST']._serialized_start=978
  _globals['_SCENARIOEXECUTIONENDINGREQUEST']._serialized_end=1148
  _globals['_STEPEXECUTIONSTARTINGREQUEST']._serialized_start=1151
  _globals['_STEPEXECUTIONSTARTINGREQUEST']._serialized_end=1311
  _globals['_STEPEXECUTIONENDINGREQUEST']._serialized_start=1314
  _globals['_STEPEXECUTIONENDINGREQUEST']._serialized_end=1472
  _globals['_EXECUTIONARG']._serialized_start=1474
  _globals['_EXECUTIONARG']._serialized_end=1525
  _globals['_EXECUTIONINFO']._serialized_start=1528
  _globals['_EXECUTIONINFO']._serialized_end=1838
  _globals['_SPECINFO']._serialized_start=1840
  _globals['_SPECINFO']._serialized_end=1914
  _globals['_SCENARIOINFO']._serialized_start=1916
  _globals['_SCENARIOINFO']._serialized_end=1976
  _globals['_STEPINFO']._serialized_start=1978
  _globals['_STEPINFO']._serialized_end=2098
  _globals['_EXECUTESTEPREQUEST']._serialized_start=2101
  _globals['_EXECUTESTEPREQUEST']._serialized_end=2257
  _globals['_STEPVALIDATEREQUEST']._serialized_start=2259
  _globals['_STEPVALIDATEREQUEST']._serialized_end=2377
  _globals['_STEPVALIDATERESPONSE']._serialized_start=2380
  _globals['_STEPVALIDATERESPONSE']._serialized_end=2611
  _globals['_STEPVALIDATERESPONSE_ERRORTYPE']._serialized_start=2530
  _globals['_STEPVALIDATERESPONSE_ERRORTYPE']._serialized_end=2611
  _globals['_SUITEEXECUTIONRESULT']._serialized_start=2613
  _globals['_SUITEEXECUTIONRESULT']._serialized_end=2690
  _globals['_SUITEEXECUTIONRESULTITEM']._serialized_start=2692
  _globals['_SUITEEXECUTIONRESULTITEM']._serialized_end=2765
  _globals['_STEPNAMESREQUEST']._serialized_start=2767
  _globals['_STEPNAMESREQUEST']._serialized_end=2785
  _globals['_STEPNAMESRESPONSE']._serialized_start=2787
  _globals['_STEPNAMESRESPONSE']._serialized_end=2821
  _globals['_SCENARIODATASTOREINITREQUEST']._serialized_start=2823
  _globals['_SCENARIODATASTOREINITREQUEST']._serialized_end=2869
  _globals['_SPECDATASTOREINITREQUEST']._serialized_start=2871
  _globals['_SPECDATASTOREINITREQUEST']._serialized_end=2913
  _globals['_SUITEDATASTOREINITREQUEST']._serialized_start=2915
  _globals['_SUITEDATASTOREINITREQUEST']._serialized_end=2958
  _globals['_PARAMETERPOSITION']._serialized_start=2960
  _globals['_PARAMETERPOSITION']._serialized_end=3021
  _globals['_REFACTORREQUEST']._serialized_start=3024
  _globals['_REFACTORREQUEST']._serialized_end=3229
  _globals['_FILECHANGES']._serialized_start=3231
  _globals['_FILECHANGES']._serialized_end=3328
  _globals['_REFACTORRESPONSE']._serialized_start=3330
  _globals['_REFACTORRESPONSE']._serialized_end=3452
  _globals['_STEPNAMEREQUEST']._serialized_start=3454
  _globals['_STEPNAMEREQUEST']._serialized_end=3490
  _globals['_STEPNAMERESPONSE']._serialized_start=3493
  _globals['_STEPNAMERESPONSE']._serialized_end=3644
  _globals['_UNSUPPORTEDMESSAGERESPONSE']._serialized_start=3646
  _globals['_UNSUPPORTEDMESSAGERESPONSE']._serialized_end=3691
  _globals['_CACHEFILEREQUEST']._serialized_start=3694
  _globals['_CACHEFILEREQUEST']._serialized_end=3903
  _globals['_CACHEFILEREQUEST_FILESTATUS']._serialized_start=3828
  _globals['_CACHEFILEREQUEST_FILESTATUS']._serialized_end=3903
  _globals['_STEPPOSITIONSREQUEST']._serialized_start=3905
  _globals['_STEPPOSITIONSREQUEST']._serialized_end=3945
  _globals['_STEPPOSITIONSRESPONSE']._serialized_start=3948
  _globals['_STEPPOSITIONSRESPONSE']._serialized_end=4132
  _globals['_STEPPOSITIONSRESPONSE_STEPPOSITION']._serialized_start=4063
  _globals['_STEPPOSITIONSRESPONSE_STEPPOSITION']._serialized_end=4132
  _globals['_IMPLEMENTATIONFILEGLOBPATTERNREQUEST']._serialized_start=4134
  _globals['_IMPLEMENTATIONFILEGLOBPATTERNREQUEST']._serialized_end=4172
  _globals['_IMPLEMENTATIONFILEGLOBPATTERNRESPONSE']._serialized_start=4174
  _globals['_IMPLEMENTATIONFILEGLOBPATTERNRESPONSE']._serialized_end=4235
  _globals['_IMPLEMENTATIONFILELISTREQUEST']._serialized_start=4237
  _globals['_IMPLEMENTATIONFILELISTREQUEST']._serialized_end=4268
  _globals['_IMPLEMENTATIONFILELISTRESPONSE']._serialized_start=4270
  _globals['_IMPLEMENTATIONFILELISTRESPONSE']._serialized_end=4335
  _globals['_STUBIMPLEMENTATIONCODEREQUEST']._serialized_start=4337
  _globals['_STUBIMPLEMENTATIONCODEREQUEST']._serialized_end=4415
  _globals['_TEXTDIFF']._serialized_start=4417
  _globals['_TEXTDIFF']._serialized_end=4480
  _globals['_FILEDIFF']._serialized_start=4482
  _globals['_FILEDIFF']._serialized_end=4555
  _globals['_KEEPALIVE']._serialized_start=4557
  _globals['_KEEPALIVE']._serialized_end=4586
  _globals['_SPECDETAILS']._serialized_start=4589
  _globals['_SPECDETAILS']._serialized_end=4758
  _globals['_SPECDETAILS_SPECDETAIL']._serialized_start=4661
  _globals['_SPECDETAILS_SPECDETAIL']._serialized_end=4758
  _globals['_EMPTY']._serialized_start=4760
  _globals['_EMPTY']._serialized_end=4767
  _globals['_MESSAGE']._serialized_start=4770
  _globals['_MESSAGE']._serialized_end=8351
  _globals['_MESSAGE_MESSAGETYPE']._serialized_start=7421
  _globals['_MESSAGE_MESSAGETYPE']._serialized_end=8351
# @@protoc_insertion_point(module_scope)



import os
import sys
import tempfile
import unittest

from getgauge import processor
from getgauge.messages.messages_pb2 import Message, ParameterPosition
from getgauge.registry import registry


class RefactorTests(unittest.TestCase):
    file = None
    data = None
    path = ''

    def setUp(self):
        self.preservesNewlines = True
        RefactorTests.path = os.path.join(tempfile.gettempdir(), 'step_impl.py')
        RefactorTests.file = open(RefactorTests.path, 'w')
        RefactorTests.file.write("""@step("Vowels in English language are <vowels>.")
def assert_default_vowels(arg0):
    Messages.write_message("Given vowels are {0}".format(given_vowels))
    assert given_vowels == "".join(vowels)\n""")
        RefactorTests.file.close()
        RefactorTests.file = open(RefactorTests.path, 'r')
        RefactorTests.data = RefactorTests.file.read()
        RefactorTests.file.close()
        registry.add_step('Vowels in English language are <vowels>.', None,
                          RefactorTests.path)

    def tearDown(self):
        registry.clear()

    def test_Processor_refactor_request_with_add_param(self):
        response = Message()
        request = Message()
        request.refactorRequest.saveChanges = True
        request.refactorRequest.oldStepValue.stepValue = 'Vowels in English language are {}.'
        request.refactorRequest.oldStepValue.parameters.append('vowels')
        request.refactorRequest.newStepValue.parameterizedStepValue = 'Vowels in English language is \
<vowels> <bsdfdsf>.'
        request.refactorRequest.newStepValue.stepValue = 'Vowels in English language is {} {}.'
        request.refactorRequest.newStepValue.parameters.extend(['vowels', 'bsdfdsf'])
        position = ParameterPosition()
        position.oldPosition = 0
        position.newPosition = 0
        param_position = ParameterPosition()
        param_position.oldPosition = -1
        param_position.newPosition = 1
        request.refactorRequest.paramPositions.extend([position, param_position])

        processor.refactor_step(request.refactorRequest, response, None)
        actual_data = self.getActualText()

        self.assertEqual(Message.RefactorResponse, response.messageType)
        self.assertEqual(True,
                         response.refactorResponse.success,
                         response.refactorResponse.error)

        self.assertEqual([RefactorTests.path],
                         response.refactorResponse.filesChanged)

        expected = """@step("Vowels in English language is <vowels> <bsdfdsf>.")
def assert_default_vowels(arg0, arg1):
    Messages.write_message("Given vowels are {0}".format(given_vowels))
    assert given_vowels == "".join(vowels)
"""
        self.assertEqual(expected, actual_data)

    def test_Processor_refactor_request_with_add_param_and_invalid_identifier(self):
        response = Message()
        request = Message()
        request.refactorRequest.saveChanges = True
        request.refactorRequest.oldStepValue.stepValue = 'Vowels in English language are {}.'
        request.refactorRequest.oldStepValue.parameters.append('vowels')
        request.refactorRequest.newStepValue.parameterizedStepValue = 'Vowels in English language is \
<vowels> <vowels!2_ab%$>.'
        request.refactorRequest.newStepValue.stepValue = 'Vowels in English language is {} {}.'
        request.refactorRequest.newStepValue.parameters.extend(['vowels', 'vowels!2_ab%$'])
        position = ParameterPosition()
        position.oldPosition = 0
        position.newPosition = 0
        param_position = ParameterPosition()
        param_position.oldPosition = -1
        param_position.newPosition = 1
        request.refactorRequest.paramPositions.extend([position, param_position])

        processor.refactor_step(request.refactorRequest, response, None)
        actual_data = self.getActualText()

        self.assertEqual(Message.RefactorResponse, response.messageType)
        self.assertEqual(True,
                         response.refactorResponse.success,
                         response.refactorResponse.error)

        self.assertEqual([RefactorTests.path],
                         response.refactorResponse.filesChanged)

        expected = """@step("Vowels in English language is <vowels> <vowels!2_ab%$>.")
def assert_default_vowels(arg0, arg1):
    Messages.write_message("Given vowels are {0}".format(given_vowels))
    assert given_vowels == "".join(vowels)
"""
        self.assertEqual(expected, actual_data)

    def test_Processor_refactor_request_with_add_param_and_only_invalid_identifier(self):
        response = Message()
        request = Message()
        request.refactorRequest.saveChanges = True
        request.refactorRequest.oldStepValue.stepValue = 'Vowels in English language are {}.'
        request.refactorRequest.oldStepValue.parameters.append('vowels')
        request.refactorRequest.newStepValue.parameterizedStepValue = 'Vowels in English language is \
<vowels> <!%$>.'
        request.refactorRequest.newStepValue.stepValue = 'Vowels in English language is {} {}.'
        request.refactorRequest.newStepValue.parameters.extend(['vowels', '!%$'])
        position = ParameterPosition()
        position.oldPosition = 0
        position.newPosition = 0
        param_position = ParameterPosition()
        param_position.oldPosition = -1
        param_position.newPosition = 1
        request.refactorRequest.paramPositions.extend([position, param_position])

        processor.refactor_step(request.refactorRequest, response, None)
        actual_data = self.getActualText()

        self.assertEqual(Message.RefactorResponse, response.messageType)
        self.assertEqual(True,
                         response.refactorResponse.success,
                         response.refactorResponse.error)

        self.assertEqual([RefactorTests.path],
                         response.refactorResponse.filesChanged)

        expected = """@step("Vowels in English language is <vowels> <!%$>.")
def assert_default_vowels(arg0, arg1):
    Messages.write_message("Given vowels are {0}".format(given_vowels))
    assert given_vowels == "".join(vowels)
"""
        self.assertEqual(expected, actual_data)

    def test_Processor_refactor_request_with_remove_param(self):
        response = Message()
        request = Message()
        request.refactorRequest.saveChanges = True
        request.refactorRequest.oldStepValue.stepValue = 'Vowels in English language are {}.'
        request.refactorRequest.oldStepValue.parameters.append('vowels')
        request.refactorRequest.newStepValue.parameterizedStepValue = 'Vowels in English language is.'
        request.refactorRequest.newStepValue.stepValue = 'Vowels in English language is.'

        processor.refactor_step(request.refactorRequest, response, None)

        actual_data = self.getActualText()

        self.assertEqual(Message.RefactorResponse, response.messageType)
        self.assertEqual(True,
                         response.refactorResponse.success,
                         response.refactorResponse.error)

        self.assertEqual([RefactorTests.path],
                         response.refactorResponse.filesChanged)

        expected = """@step("Vowels in English language is.")
def assert_default_vowels():
    Messages.write_message("Given vowels are {0}".format(given_vowels))
    assert given_vowels == "".join(vowels)
"""
        self.assertEqual(expected, actual_data)

    def test_Processor_refactor_request(self):
        response = Message()
        request = Message()
        request.refactorRequest.saveChanges = True
        request.refactorRequest.oldStepValue.stepValue = 'Vowels in English language are {}.'
        request.refactorRequest.oldStepValue.parameters.append('vowels')
        request.refactorRequest.newStepValue.parameterizedStepValue = 'Vowels in English language is <vowels>.'
        request.refactorRequest.newStepValue.stepValue = 'Vowels in English language is {}.'
        request.refactorRequest.newStepValue.parameters.extend(['vowels'])
        position = ParameterPosition()
        position.oldPosition = 0
        position.newPosition = 0
        request.refactorRequest.paramPositions.extend([position])

        processor.refactor_step(request.refactorRequest, response, None)

        actual_data = self.getActualText()

        self.assertEqual(Message.RefactorResponse, response.messageType)
        self.assertEqual(True,
                         response.refactorResponse.success,
                         response.refactorResponse.error)

        self.assertEqual([RefactorTests.path],
                         response.refactorResponse.filesChanged)

        expected = """@step("Vowels in English language is <vowels>.")
def assert_default_vowels(arg0):
    Messages.write_message("Given vowels are {0}".format(given_vowels))
    assert given_vowels == "".join(vowels)
"""
        self.assertEqual(expected, actual_data)

    def test_Processor_refactor_request_with_add_and_remove_param(self):
        response = Message()
        request = Message()
        request.refactorRequest.saveChanges = True
        request.refactorRequest.oldStepValue.stepValue = 'Vowels in English language are {}.'
        request.refactorRequest.oldStepValue.parameters.append('vowels')
        request.refactorRequest.newStepValue.parameterizedStepValue = 'Vowels in English language is <bsdfdsf>.'
        request.refactorRequest.newStepValue.stepValue = 'Vowels in English language is {}.'
        request.refactorRequest.newStepValue.parameters.extend(['bsdfdsf'])
        param_position = ParameterPosition()
        param_position.oldPosition = -1
        param_position.newPosition = 0
        request.refactorRequest.paramPositions.extend([param_position])

        processor.refactor_step(request.refactorRequest, response, None)

        actual_data = self.getActualText()

        self.assertEqual(Message.RefactorResponse, response.messageType)
        self.assertEqual(True,
                         response.refactorResponse.success,
                         response.refactorResponse.error)

        self.assertEqual([RefactorTests.path],
                         response.refactorResponse.filesChanged)

        expected = """@step("Vowels in English language is <bsdfdsf>.")
def assert_default_vowels(arg1):
    Messages.write_message("Given vowels are {0}".format(given_vowels))
    assert given_vowels == "".join(vowels)
"""
        self.assertEqual(expected, actual_data)

    def test_processor_refactor_request_with_insert_param(self):
        response = Message()
        request = Message()
        request.refactorRequest.saveChanges = True

        request.refactorRequest.oldStepValue.stepValue = 'Vowels in English language are {}.'
        request.refactorRequest.oldStepValue.parameters.append('vowels')
        request.refactorRequest.oldStepValue.parameterizedStepValue = 'Vowels in English language are <vowels>.'

        request.refactorRequest.newStepValue.stepValue = 'Vowels in English language is {} {}.'
        request.refactorRequest.newStepValue.parameterizedStepValue = 'Vowels in English language is <a> <vowels>.'
        request.refactorRequest.newStepValue.parameters.extend(['a', 'vowels'])
        param1_position = ParameterPosition()
        param1_position.oldPosition = -1
        param1_position.newPosition = 0

        param2_position = ParameterPosition()
        param2_position.oldPosition = 0
        param2_position.newPosition = 1
        request.refactorRequest.paramPositions.extend([param1_position, param2_position])

        processor.refactor_step(request.refactorRequest, response, None)

        actual_data = self.getActualText()

        self.assertEqual(Message.RefactorResponse, response.messageType)
        self.assertEqual(True,
                         response.refactorResponse.success,
                         response.refactorResponse.error)

        self.assertEqual([RefactorTests.path],
                         response.refactorResponse.filesChanged)

        expected = """@step("Vowels in English language is <a> <vowels>.")
def assert_default_vowels(arg1, arg0):
    Messages.write_message("Given vowels are {0}".format(given_vowels))
    assert given_vowels == "".join(vowels)
"""
        self.assertEqual(expected, actual_data)

    def test_Processor_refactor_request_without_save_change_with_add_param(self):
        response = Message()
        request = Message()

        request.refactorRequest.saveChanges = False
        request.refactorRequest.oldStepValue.stepValue = 'Vowels in English language are {}.'
        request.refactorRequest.oldStepValue.parameters.append('vowels')
        request.refactorRequest.newStepValue.parameterizedStepValue = 'Vowels in English language \
is <vowels> <bsdfdsf>.'
        request.refactorRequest.newStepValue.stepValue = 'Vowels in English language is {} {}.'
        request.refactorRequest.newStepValue.parameters.extend(['vowels', 'bsdfdsf'])
        position = ParameterPosition()
        position.oldPosition = 0
        position.newPosition = 0
        param_position = ParameterPosition()
        param_position.oldPosition = -1
        param_position.newPosition = 1
        request.refactorRequest.paramPositions.extend([position, param_position])

        old_content = self.getActualText()

        processor.refactor_step(request.refactorRequest, response, None)

        expected = """@step("Vowels in English language is <vowels> <bsdfdsf>.")
def assert_default_vowels(arg0, arg1):
    Messages.write_message("Given vowels are {0}".format(given_vowels))
    assert given_vowels == "".join(vowels)
"""

        self.assertEqual(Message.RefactorResponse, response.messageType)
        self.assertEqual(True,
                         response.refactorResponse.success,
                         response.refactorResponse.error)

        self.assertEqual([RefactorTests.path],
                         response.refactorResponse.filesChanged)

        self.assertEqual(RefactorTests.path, response.refactorResponse.fileChanges[0].fileName)
        self.assertEqual(expected, response.refactorResponse.fileChanges[0].fileContent)
        self.assertEqual(old_content, self.getActualText())

    def test_Processor_refactor_request_without_save_changes_add_param_and_invalid_identifier(self):
        response = Message()
        request = Message()

        request.refactorRequest.saveChanges = False
        request.refactorRequest.oldStepValue.stepValue = 'Vowels in English language are {}.'
        request.refactorRequest.oldStepValue.parameters.append('vowels')
        request.refactorRequest.newStepValue.parameterizedStepValue = 'Vowels in English language is \
<vowels> <vowels!2_ab%$>.'
        request.refactorRequest.newStepValue.stepValue = 'Vowels in English language is {} {}.'
        request.refactorRequest.newStepValue.parameters.extend(['vowels', 'vowels!2_ab%$'])
        position = ParameterPosition()
        position.oldPosition = 0
        position.newPosition = 0
        param_position = ParameterPosition()
        param_position.oldPosition = -1
        param_position.newPosition = 1
        request.refactorRequest.paramPositions.extend([position, param_position])

        old_content = self.getActualText()

        processor.refactor_step(request.refactorRequest, response, None)

        self.assertEqual(Message.RefactorResponse, response.messageType)
        self.assertEqual(True,
                         response.refactorResponse.success,
                         response.refactorResponse.error)

        self.assertEqual([RefactorTests.path],
                         response.refactorResponse.filesChanged)
        expected = """@step("Vowels in English language is <vowels> <vowels!2_ab%$>.")
def assert_default_vowels(arg0, arg1):
    Messages.write_message("Given vowels are {0}".format(given_vowels))
    assert given_vowels == "".join(vowels)
"""
        self.assertEqual(expected, response.refactorResponse.fileChanges[0].fileContent)
        self.assertEqual(old_content, self.getActualText())
        diff_contents = [diff.content for diff in response.refactorResponse.fileChanges[0].diffs]
        self.assertIn('"Vowels in English language is <vowels> <vowels!2_ab%$>."', diff_contents)
        self.assertIn('arg0, arg1', diff_contents)

    def getActualText(self):
        _file = open(RefactorTests.path, 'r+')
        actual_data = _file.read()
        _file.seek(0)
        _file.truncate()
        _file.write(RefactorTests.data)
        _file.close()
        return actual_data

